==> ansible-11.0.0a1.tar.gz: ansible-11.0.0a1/ansible_collections/cisco/dnac/plugins/modules/ise_integration_status_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: ise_integration_status_info
short_description: Information module for Ise Integration Status
description:
- Get all Ise Integration Status.
- API to check Cisco ISE server integration status.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
- dnacentersdk >= 2.7.2
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for System Settings CiscoISEServerIntegrationStatus
  description: Complete reference of the CiscoISEServerIntegrationStatus API.
  link: https://developer.cisco.com/docs/dna-center/#!cisco-ise-server-integration-status
notes:
  - SDK Method used are
    system_settings.SystemSettings.cisco_ise_server_integration_status,

  - Paths used are
    get /dna/intent/api/v1/ise-integration-status,

"""

EXAMPLES = r"""
- name: Get all Ise Integration Status
  cisco.dnac.ise_integration_status_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "aaaServerSettingId": "string",
      "overallStatus": "string",
      "overallErrorMessage": "string",
      "steps": [
        {
          "stepId": "string",
          "stepOrder": 0,
          "stepName": "string",
          "stepDescription": "string",
          "stepStatus": "string",
          "certAcceptedByUser": true,
          "stepTime": 0
        }
      ]
    }
"""

==> ansible-12.0.0a8.tar.gz: ansible-12.0.0a8/ansible_collections/cisco/dnac/plugins/modules/ise_integration_status_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: ise_integration_status_info
short_description: Information module for Ise Integration
  Status
description:
  - Get all Ise Integration Status.
  - API to check Cisco ISE server integration status.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for System
      Settings CiscoISEServerIntegrationStatus
    description: Complete reference of the CiscoISEServerIntegrationStatus
      API.
    link: https://developer.cisco.com/docs/dna-center/#!cisco-ise-server-integration-status
notes:
  - SDK Method used are
    system_settings.SystemSettings.cisco_ise_server_integration_status,
  - Paths used are
    get /dna/intent/api/v1/ise-integration-status,
"""

EXAMPLES = r"""
---
- name: Get all Ise Integration Status
  cisco.dnac.ise_integration_status_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "aaaServerSettingId": "string",
      "overallStatus": "string",
      "overallErrorMessage": "string",
      "steps": [
        {
          "stepId": "string",
          "stepOrder": 0,
          "stepName": "string",
          "stepDescription": "string",
          "stepStatus": "string",
          "certAcceptedByUser": true,
          "stepTime": 0
        }
      ]
    }
"""
